==> qore-2.1.1.tar.bz2: qore-2.1.1/docs/modules/ConnectionProvider/html/struct_connection_provider_1_1_connection_info.js <==
var struct_connection_provider_1_1_connection_info =
[
    [ "children_can_support_apis", "struct_connection_provider_1_1_connection_info.html#a6908e53a0869b9bf9334e32fa788b4e6", null ],
    [ "children_can_support_messages", "struct_connection_provider_1_1_connection_info.html#a8f4b8119847bf1e208fc787533001ae9", null ],
    [ "children_can_support_observers", "struct_connection_provider_1_1_connection_info.html#ae3b2d8d54f87e7043cd6606cd3d9edf2", null ],
    [ "children_can_support_records", "struct_connection_provider_1_1_connection_info.html#a23ad288449b08ed16377e49b136ebcc8", null ],
    [ "children_can_support_transactions", "struct_connection_provider_1_1_connection_info.html#ac08874f7607a3e3c49c5293a0cbe2751", null ],
    [ "customization_status", "struct_connection_provider_1_1_connection_info.html#a5346695ea5f83d1c68f5f77341f02e75", null ],
    [ "customization_timestamp", "struct_connection_provider_1_1_connection_info.html#af1375f6d70b86fafef8a59bcfc7f9274", null ],
    [ "dataprovider_subtypes", "struct_connection_provider_1_1_connection_info.html#ad59b5760c3b9d061279f0baf5785e092", null ],
    [ "debug_data", "struct_connection_provider_1_1_connection_info.html#ad618785c99a2f05d5176bdc025918288", null ],
    [ "desc", "struct_connection_provider_1_1_connection_info.html#af3c96a4f89291d9e16c5bee9df0fb58f", null ],
    [ "display_name", "struct_connection_provider_1_1_connection_info.html#ae7c190c1325ae8a0fdfb402264b7edd1", null ],
    [ "enabled", "struct_connection_provider_1_1_connection_info.html#acedc50afa1d2f8578491282ad7efcd2e", null ],
    [ "features", "struct_connection_provider_1_1_connection_info.html#ab1f4c5a981e32a9439d43f20997bf5ab", null ],
    [ "has_provider", "struct_connection_provider_1_1_connection_info.html#a36b555213d9adb5280c1dfba0a911800", null ],
    [ "last_check", "struct_connection_provider_1_1_connection_info.html#a5224a55ff712f8b577552c20b30b8f26", null ],
    [ "locked", "struct_connection_provider_1_1_connection_info.html#a9d2234f1d65978141ffed4f3c8872866", null ],
    [ "loopback", "struct_connection_provider_1_1_connection_info.html#a268a8ec1c00f8a903adf5e096eef4fb3", null ],
    [ "monitor", "struct_connection_provider_1_1_connection_info.html#a69242fe5bf41bc171351f11d5dd3f685", null ],
    [ "name", "struct_connection_provider_1_1_connection_info.html#ab8c01a9e0bbcfd5d14c5ecaf841ef616", null ],
    [ "needs_auth", "struct_connection_provider_1_1_connection_info.html#ac8f8c9b415139828731e3331c40845da", null ],
    [ "opts", "struct_connection_provider_1_1_connection_info.html#a633e4ae13939ec27d9a7afbb30652619", null ],
    [ "short_desc", "struct_connection_provider_1_1_connection_info.html#a664f35ff46a3f1f30a307128a3acf35a", null ],
    [ "status", "struct_connection_provider_1_1_connection_info.html#ae9aa6d1f2e7c8e3516336953c77a375d", null ],
    [ "supports_customization", "struct_connection_provider_1_1_connection_info.html#a7fadf375e1ff3356fc4ac9ec82b1affa", null ],
    [ "tags", "struct_connection_provider_1_1_connection_info.html#a06b5b40379ebde828819e99c5ba7d4ff", null ],
    [ "type", "struct_connection_provider_1_1_connection_info.html#ac5269ba23ad36e29a6f9f9d1073d153d", null ],
    [ "up", "struct_connection_provider_1_1_connection_info.html#a73376e8fe53016b853e1a7d41c923ab6", null ],
    [ "updated", "struct_connection_provider_1_1_connection_info.html#acd4d393e892ad541f16139f63221aa6c", null ],
    [ "url", "struct_connection_provider_1_1_connection_info.html#af91b135af69fe8f07cc1f90dd16ef86a", null ],
    [ "url_hash", "struct_connection_provider_1_1_connection_info.html#af993067b49e9f27202cba725374807be", null ]
];

==> qore-2.2.0.tar.bz2: qore-2.2.0/docs/modules/ConnectionProvider/html/struct_connection_provider_1_1_connection_info.js <==
var struct_connection_provider_1_1_connection_info =
[
    [ "app", "struct_connection_provider_1_1_connection_info.html#aa0ee97f192c6af0a7ea29c30acaaa4da", null ],
    [ "children_can_support_apis", "struct_connection_provider_1_1_connection_info.html#a6908e53a0869b9bf9334e32fa788b4e6", null ],
    [ "children_can_support_messages", "struct_connection_provider_1_1_connection_info.html#a8f4b8119847bf1e208fc787533001ae9", null ],
    [ "children_can_support_observers", "struct_connection_provider_1_1_connection_info.html#ae3b2d8d54f87e7043cd6606cd3d9edf2", null ],
    [ "children_can_support_records", "struct_connection_provider_1_1_connection_info.html#a23ad288449b08ed16377e49b136ebcc8", null ],
    [ "children_can_support_transactions", "struct_connection_provider_1_1_connection_info.html#ac08874f7607a3e3c49c5293a0cbe2751", null ],
    [ "customization_status", "struct_connection_provider_1_1_connection_info.html#a5346695ea5f83d1c68f5f77341f02e75", null ],
    [ "customization_timestamp", "struct_connection_provider_1_1_connection_info.html#af1375f6d70b86fafef8a59bcfc7f9274", null ],
    [ "dataprovider_subtypes", "struct_connection_provider_1_1_connection_info.html#ad59b5760c3b9d061279f0baf5785e092", null ],
    [ "debug_data", "struct_connection_provider_1_1_connection_info.html#ad618785c99a2f05d5176bdc025918288", null ],
    [ "desc", "struct_connection_provider_1_1_connection_info.html#af3c96a4f89291d9e16c5bee9df0fb58f", null ],
    [ "display_name", "struct_connection_provider_1_1_connection_info.html#ae7c190c1325ae8a0fdfb402264b7edd1", null ],
    [ "enabled", "struct_connection_provider_1_1_connection_info.html#acedc50afa1d2f8578491282ad7efcd2e", null ],
    [ "features", "struct_connection_provider_1_1_connection_info.html#ab1f4c5a981e32a9439d43f20997bf5ab", null ],
    [ "has_provider", "struct_connection_provider_1_1_connection_info.html#a36b555213d9adb5280c1dfba0a911800", null ],
    [ "last_check", "struct_connection_provider_1_1_connection_info.html#a5224a55ff712f8b577552c20b30b8f26", null ],
    [ "locked", "struct_connection_provider_1_1_connection_info.html#a9d2234f1d65978141ffed4f3c8872866", null ],
    [ "loopback", "struct_connection_provider_1_1_connection_info.html#a268a8ec1c00f8a903adf5e096eef4fb3", null ],
    [ "monitor", "struct_connection_provider_1_1_connection_info.html#a69242fe5bf41bc171351f11d5dd3f685", null ],
    [ "name", "struct_connection_provider_1_1_connection_info.html#ab8c01a9e0bbcfd5d14c5ecaf841ef616", null ],
    [ "needs_auth", "struct_connection_provider_1_1_connection_info.html#ac8f8c9b415139828731e3331c40845da", null ],
    [ "opts", "struct_connection_provider_1_1_connection_info.html#a633e4ae13939ec27d9a7afbb30652619", null ],
    [ "short_desc", "struct_connection_provider_1_1_connection_info.html#a664f35ff46a3f1f30a307128a3acf35a", null ],
    [ "status", "struct_connection_provider_1_1_connection_info.html#ae9aa6d1f2e7c8e3516336953c77a375d", null ],
    [ "supports_customization", "struct_connection_provider_1_1_connection_info.html#a7fadf375e1ff3356fc4ac9ec82b1affa", null ],
    [ "tags", "struct_connection_provider_1_1_connection_info.html#a06b5b40379ebde828819e99c5ba7d4ff", null ],
    [ "type", "struct_connection_provider_1_1_connection_info.html#ac5269ba23ad36e29a6f9f9d1073d153d", null ],
    [ "up", "struct_connection_provider_1_1_connection_info.html#a73376e8fe53016b853e1a7d41c923ab6", null ],
    [ "updated", "struct_connection_provider_1_1_connection_info.html#acd4d393e892ad541f16139f63221aa6c", null ],
    [ "url", "struct_connection_provider_1_1_connection_info.html#af91b135af69fe8f07cc1f90dd16ef86a", null ],
    [ "url_hash", "struct_connection_provider_1_1_connection_info.html#af993067b49e9f27202cba725374807be", null ]
];
